Error

Enum Error 

pub enum Error {
    UnknownKeyIdentifier,
    AlgorithmNotSupported,
    CanisterIdMissing,
    InvalidPath,
}
Error that can occur during public key derivation

Variants



UnknownKeyIdentifier

The specified master public key is not known



AlgorithmNotSupported

The algorithm is not supported (possibly due to an unset feature)



CanisterIdMissing

The canister must be specified in the argument structs since the library has no other way of determining the correct value, and the canister id is a necessary component of the key derivation.



InvalidPath

The derivation path is not valid for this algorithm

This mostly affects VetKD derivation, which only supports a single context string rather than a sequence of them.